.. _mainfuncs:

BASTA main functions
********************

The main BASTA programme
========================

.. automodule:: bastamain
   :members:

.. _constants:

The constants module
====================

.. automodule:: constants
   :members:

The distance module
===================

.. automodule:: distances
   :members:

The asteroseismic module
========================

.. automodule:: freq_fit
   :members:

.. automodule:: glitch_fit
   :members:

The stats module
================

.. automodule:: priors
   :members:

.. automodule:: process_output
   :members:

.. automodule:: stats
   :members:
